@@ -16,7 +16,7 @@ CONFIG_PATH = "/etc/allo-config.dict"
 
 ALLO_URL = "10.204.22.1:3025" \
     if os.getenv("ALLOENV") == "TEST" \
-    else "teleport.libriciel.fr:443"
+    else "update.libriciel.fr:443"
 
 API_PATH = "https://{}/v1/webapi".format("10.204.22.1:3080") \
     if os.getenv("ALLOENV") == "TEST" \
